@@ -1,9 +1,6 @@
 #!/bin/sh
 
-# clang: error: invalid deployment target for -stdlib=libc++
-export MACOSX_DEPLOYMENT_TARGET=10.7
-
-make
+make -j${CPU_COUNT}
 
 install -d ${PREFIX}/lib
 # filter libtbb.dylib ( or .so ), libtbbmalloc.dylib ( or .so )
@@ -14,5 +11,5 @@ install -d ${PREFIX}/include
 cp -r ./include/tbb ${PREFIX}/include
 
 # simple test instead of "make test" to avoid timeout
-c++ ${RECIPE_DIR}/tbb_example.c -I${PREFIX}/include -L${PREFIX}/lib -ltbb -o tbb_example
+${CXX} ${RECIPE_DIR}/tbb_example.c -I${PREFIX}/include -L${PREFIX}/lib -ltbb -o tbb_example
 DYLD_LIBRARY_PATH=${PREFIX}/lib ./tbb_example
